#========================================================================================
# package      DE_EPAGES::Spreedly::UI::PaymentMethodSpreedlyPaymentez
# base         DE_EPAGES::Spreedly::UI::PaymentMethodSpreedly
# state        private
#----------------------------------------------------------------------------------------
# description  UI Controller for PaymentMethodSpreedlyPaymentez
#========================================================================================
package DE_EPAGES::Spreedly::UI::PaymentMethodSpreedlyPaymentez;
use base DE_EPAGES::Spreedly::UI::PaymentMethodSpreedly;

use DE_EPAGES::Core::API::PerlTools qw ( isValid );
use strict;

use constant PAYMENT_TYPE_PAYMENTEZ => 'SpreedlyPaymentez';

#========================================================================================
# function     ViewSettings
# state        public
#----------------------------------------------------------------------------------------
# syntax       ViewSettings( $Servlet );
#----------------------------------------------------------------------------------------
# description  UI Controller to view settings on the MBO settings page.
#----------------------------------------------------------------------------------------
# input        $Servlet | Servlet | DE_EPAGES::Presentation::Servlet::BasePermission
#========================================================================================
sub ViewSettingsSpreedlyPaymentez {
    my $self = shift;
    my ($Servlet,$PaymentMethod) = @_;

    my $Form = $Servlet->form();
    my $ApplicationCode = $Form->value('ApiCode');
    my $AppKey = $Form->value('ApiKey');

    if (isValid($ApplicationCode) && isValid($AppKey)) {
        $self->_createGateway($ApplicationCode, $AppKey, $Servlet);
    }

    return $Servlet;
}

#========================================================================================
# function     SaveSettings
# state        public
#----------------------------------------------------------------------------------------
# syntax       SaveSettings( $Servlet );
#----------------------------------------------------------------------------------------
# description  UI Controller to save settings on the MBO settings page.
#----------------------------------------------------------------------------------------
# input        $Servlet | Servlet | DE_EPAGES::Presentation::Servlet::BasePermission
#========================================================================================
sub SaveSettings {
    my $self = shift;
    my ($Servlet) = @_;

    my $PaymentMethod = $Servlet->object();
    $Servlet->form->form($PaymentMethod, 'SpreedlyPaymentezSettings');

    $self->SUPER::SaveSettings($Servlet);

}

#---------------------------------------------------------------------------
#  Private methods
#---------------------------------------------------------------------------
sub _createGateway {
    my $self = shift;
    my ($ApplicationCode, $AppKey, $Servlet) = @_;

    my $hAdditionalBodyParams = {
        'application_code' => $ApplicationCode,
        'app_key' => $AppKey,
    };

    my $PaymentMethodSpreedly = DE_EPAGES::Spreedly::UI::PaymentMethodSpreedly->new();
    $PaymentMethodSpreedly->SaveCredentials($Servlet, PAYMENT_TYPE_PAYMENTEZ, $hAdditionalBodyParams);

    return;
}

1;
